==> java-cxf-spring-server-generator-0.11.0.tgz: package/test-output/junit4/one-of-discriminator.yml/src/test/java/com/example/PetApiTest.java <==
package com.example;

import static org.junit.Assert.*;

import javax.ws.rs.core.Response;

import org.apache.cxf.endpoint.Server;
import org.apache.cxf.jaxrs.client.JAXRSClientFactory;
import org.apache.cxf.jaxrs.client.WebClient;
import org.apache.cxf.jaxrs.spring.JAXRSServerFactoryBeanDefinitionParser.SpringJAXRSServerFactoryBean;
import org.apache.cxf.transport.local.LocalConduit;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;

@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(classes = { TestConfiguration.class })
public class PetApiTest {
	
	private static Server server;
	private com.example.PetApi api;
	
	@Autowired
	private SpringJAXRSServerFactoryBean serverFactory;

	@Before
	public void setup() throws Exception {
		server = serverFactory.create();
		api = JAXRSClientFactory.create(TestConfiguration.ENDPOINT_ADDRESS, com.example.PetApi.class, TestConfiguration.defaultProviders());
		WebClient.getConfig(api).getRequestContext().put(LocalConduit.DIRECT_DISPATCH, Boolean.TRUE);
	}
	
	@After
	public void destroy() throws Exception {
		server.stop();
		server.destroy();
	}
	
	@Test
	public void getPetTest() {
		java.lang.String id = "test";
		java.lang.Integer size = java.lang.Integer.valueOf(37);

		Response response = this.api.getPet(id, size);
		assertNotNull(response);
		com.example.model.MyResponseType result = response.readEntity(com.example.model.MyResponseType.class);
		assertNotNull(result);
	}

}

==> java-cxf-spring-server-generator-0.12.0.tgz: package/test-output/junit4/one-of-discriminator.yml/src/test/java/com/example/PetApiTest.java <==
package com.example;

import static org.junit.Assert.*;

import javax.ws.rs.core.Response;

import org.apache.cxf.endpoint.Server;
import org.apache.cxf.jaxrs.client.JAXRSClientFactory;
import org.apache.cxf.jaxrs.client.WebClient;
import org.apache.cxf.jaxrs.spring.JAXRSServerFactoryBeanDefinitionParser.SpringJAXRSServerFactoryBean;
import org.apache.cxf.transport.local.LocalConduit;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;

@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(classes = { TestConfiguration.class })
public class PetApiTest {
	
	private Server server;
	private com.example.PetApi api;
	
	@Autowired
	private SpringJAXRSServerFactoryBean serverFactory;

	@Before
	public void setup() throws Exception {
		server = serverFactory.create();
		api = JAXRSClientFactory.create(TestConfiguration.ENDPOINT_ADDRESS, com.example.PetApi.class, TestConfiguration.defaultProviders());
		WebClient.getConfig(api).getRequestContext().put(LocalConduit.DIRECT_DISPATCH, Boolean.TRUE);
	}
	
	@After
	public void destroy() throws Exception {
		server.stop();
		server.destroy();
	}
	
	@Test
	public void getPetTest() {
		java.lang.String id = "test";
		java.lang.Integer size = java.lang.Integer.valueOf(37);

		Response response = this.api.getPet(id, size);
		assertNotNull(response);
		com.example.model.MyResponseType result = response.readEntity(com.example.model.MyResponseType.class);
		assertNotNull(result);
	}

}
